==> nextcloud-23.0.5.tgz: nextcloud/apps/user_status/l10n/sc.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Istados reghentes",
    "In a meeting" : "In riunione",
    "Commuting" : "Biagende",
    "Out sick" : "In maladia",
    "Vacationing" : "In vacàntzia",
    "Working remotely" : "Traballende in remotu",
    "User status" : "Istadu de s'utente",
    "Clear status message after" : "Lìmpia su messàgiu de istadu a pustis",
    "What is your status?" : "Cale est s'istadu tuo?",
    "Set status" : "Imposta istadu",
    "Online status" : "Istadu in lìnia",
    "Status message" : "Messàgiu de istadu",
    "Clear status message" : "Lìmpia su messàgiu de istadu",
    "Set status message" : "Imposta messàgiu de istadu",
    "There was an error saving the status" : "B'at àpidu un'errore sarvende s'istadu",
    "There was an error clearing the status" : "B'at àpidu un'errore limpiende s'istadu",
    "No recent status changes" : "Perunu càmbiu de istadu reghente",
    "Away" : "Ausente",
    "Do not disturb" : "No istorbes",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Non nche ddu lìmpies",
    "Today" : "Oe",
    "This week" : "Custa chida",
    "Online" : "In lìnia",
    "Invisible" : "Invisìbile",
    "Offline" : "Fora de lìnia",
    "There was an error saving the new status" : "B'at àpidu un'errore sarvende s'istadu nou",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 ora",
    "4 hours" : "4 oras",
    "Mute all notifications" : "Istuda totu is notìficas",
    "Appear offline" : "Mustra•ti foras de lìnia",
    "What's your status?" : "Cale est s'istadu tuo?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.9.tgz: nextcloud/apps/user_status/l10n/sc.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Istados reghentes",
    "In a meeting" : "In riunione",
    "Commuting" : "Biagende",
    "Out sick" : "In maladia",
    "Vacationing" : "In vacàntzia",
    "Working remotely" : "Traballende in remotu",
    "User status" : "Istadu de s'utente",
    "Clear status after" : "Lìmpia s'istadu a pustis",
    "What is your status?" : "Cale est s'istadu tuo?",
    "Set status" : "Imposta istadu",
    "Online status" : "Istadu in lìnia",
    "Status message" : "Messàgiu de istadu",
    "Clear status message" : "Lìmpia su messàgiu de istadu",
    "Set status message" : "Imposta messàgiu de istadu",
    "There was an error saving the status" : "B'at àpidu un'errore sarvende s'istadu",
    "There was an error clearing the status" : "B'at àpidu un'errore limpiende s'istadu",
    "No recent status changes" : "Perunu càmbiu de istadu reghente",
    "Away" : "Ausente",
    "Do not disturb" : "No istorbes",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Non nche ddu lìmpies",
    "Today" : "Oe",
    "This week" : "Custa chida",
    "Online" : "In lìnia",
    "Invisible" : "Invisìbile",
    "Offline" : "Fora de lìnia",
    "There was an error saving the new status" : "B'at àpidu un'errore sarvende s'istadu nou",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 ora",
    "4 hours" : "4 oras",
    "Mute all notifications" : "Istuda totu is notìficas",
    "Appear offline" : "Mustra•ti foras de lìnia",
    "Clear status message after" : "Lìmpia su messàgiu de istadu a pustis"
},
"nplurals=2; plural=(n != 1);");
